class FlickrUploader < ActiveRecord::Base
  require 'flickraw'
  require 'find'
  require 'exifr'

  def FlickrUploader.gather(params = nil)
    FlickRaw.api_key=Parameter.value('FLICKRAPIKEY')
    FlickRaw.shared_secret=Parameter.value('FLICKRAPISHAREDSECRET')

    # Pull the configuration out of the database
    token = Parameter.value('FLICKRAPITOKEN')
    dirs = Parameter.value('FLICKRBASEDIR').split(',')
    dir_excludes = Parameter.value('FLICKREXCLUDEDIR').split(',')
    file_excludes = Parameter.value('FLICKREXCLUDEFILE').split(',')
    file_types = Parameter.value('FLICKRFILETYPES').split(',')
    
    for dir in dirs      
      Log4r::Logger['mylog'].info "     ... scanning #{dir}"
      Find.find(dir) do |path|       
        if FileTest.directory?(path)
          if dir_excludes.include?(File.basename(path).downcase)
            Find.prune       # Don't look any further into this directory.
          else            
            next
          end
        else
          flagFile = "#{path.split('.')[0..-2].join('.')}.ok"
          if file_types.include?(path.split('.')[-1].downcase) then
            if (!file_excludes.include?(File.basename(path).downcase)) then
              if (!File.exists?(flagFile) and File.size(path) > 100000) then
                Log4r::Logger['mylog'].debug "     ... #{flagFile} does not exist"
                Log4r::Logger['mylog'].debug "     ... Uploading #{File.basename(path)}"
                begin
                  d = EXIFR::JPEG.new(path).date_time
                rescue
                  Log4r::Logger['mylog'].warn "     ... date error with: #{path}"
                  d = nil
                end

                begin 
                  if d != nil then         
                    s = flickr.upload_photo path, :auth_token => token, :tags => "#{d.strftime('%Y')} #{d.strftime('%m')}", :is_friend => 1, :is_public => 0, :is_family => 1, :safety_level => 1, :content_type => 1, :hidden => 2
                  else 
                    s = flickr.upload_photo path, :auth_token => token, :tags => "unknown", :is_friend => 1, :is_public => 0, :is_family => 1, :safety_level => 1, :content_type => 1, :hidden => 2
                  end
                rescue Timeout::Error => e
                  Log4r::Logger['mylog'].error "     ... Timeout error #{path}"
                  sleep(10)                
                rescue 
                  Log4r::Logger['mylog'].error "     ... Error uploading #{path}"
                  sleep(10)
                end 

                if (s != nil) and  (s.stat.downcase == 'ok') then
                  File.open(flagFile, 'w') {|f| f.write(' ') }
                  Log4r::Logger['mylog'].debug "     ... #{File.basename(path)} uploaded successfully"
                else
                  Log4r::Logger['mylog'].error "     ... #{File.basename(path)} failed to upload"
                end
              end
          end
        end
        end
      end
    end        
  end     
end
